You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@sqoop.apache.org by ja...@apache.org on 2015/12/10 22:00:19 UTC

sqoop git commit: SQOOP-2732: Sqoop2: Integration Tests: For Oracle compatibility use decimal instead of numeric sql type

Repository: sqoop
Updated Branches:
  refs/heads/sqoop2 de7fb4f67 -> 81778c37a


SQOOP-2732: Sqoop2: Integration Tests: For Oracle compatibility use decimal instead of numeric sql type

(Abraham Fine via Jarek Jarcec Cecho)


Project: http://git-wip-us.apache.org/repos/asf/sqoop/repo
Commit: http://git-wip-us.apache.org/repos/asf/sqoop/commit/81778c37
Tree: http://git-wip-us.apache.org/repos/asf/sqoop/tree/81778c37
Diff: http://git-wip-us.apache.org/repos/asf/sqoop/diff/81778c37

Branch: refs/heads/sqoop2
Commit: 81778c37a413eb64aa38ffc397af2ca695909013
Parents: de7fb4f
Author: Jarek Jarcec Cecho <ja...@apache.org>
Authored: Thu Dec 10 21:59:23 2015 +0100
Committer: Jarek Jarcec Cecho <ja...@apache.org>
Committed: Thu Dec 10 21:59:23 2015 +0100

----------------------------------------------------------------------
 .../src/main/java/org/apache/sqoop/test/data/UbuntuReleases.java | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/sqoop/blob/81778c37/test/src/main/java/org/apache/sqoop/test/data/UbuntuReleases.java
----------------------------------------------------------------------
diff --git a/test/src/main/java/org/apache/sqoop/test/data/UbuntuReleases.java b/test/src/main/java/org/apache/sqoop/test/data/UbuntuReleases.java
index 5b75389..12bcad1 100644
--- a/test/src/main/java/org/apache/sqoop/test/data/UbuntuReleases.java
+++ b/test/src/main/java/org/apache/sqoop/test/data/UbuntuReleases.java
@@ -23,7 +23,7 @@ import org.apache.sqoop.common.test.db.TableName;
 /**
  * Releases of Ubuntu Linux.
  *
  * Purpose of this set is to cover most common data types (varchar, int, numeric, date, boolean).
  */
 public class UbuntuReleases extends DataSet {
 
@@ -38,7 +38,7 @@ public class UbuntuReleases extends DataSet {
       "id",
       "id", "int",
       "code_name", "varchar(64)",
-      "version", "numeric(4,2)",
+      "version", "decimal(4,2)",
       "release_date", "date"
     );
@@ -23,7 +23,7 @@ import org.apache.sqoop.common.test.db.TableName;
  * Releases of Ubuntu Linux.
  *
- * Purpose of this set is to cover most common data types (varchar, int, numeric, date, boolean).
+ * Purpose of this set is to cover most common data types (varchar, int, decimal, date, boolean).
  */
 public class UbuntuReleases extends DataSet {